#
# spec file for package openSUSEway
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sway_version %(rpm -q --queryformat "%%{version}" sway)
%define waybar_version %(rpm -q --queryformat "%%{version}" waybar)

Name:           openSUSEway
Version:        0.15.2
Release:        1.1
Summary:        The openSUSEway desktop environment meta package
License:        MIT
Group:          Metapackages
URL:            https://github.com/openSUSE/openSUSEway
Source0:        https://github.com/openSUSE/openSUSEway/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE add-configuration-for-play-pause-next-prev-multimedi.patch gh#openSUSE/openSUSEway#41 mcepl@suse.com
# Add multimedia keys configuration
BuildArch:      noarch
BuildRequires:  aaa_base
BuildRequires:  pkgconfig(systemd)
Requires:       NetworkManager
Requires:       aaa_base
Recommends:     adwaita-qt5
Requires:       bzip2
Requires:       command-not-found
Requires:       curl
Recommends:     firefox
Requires:       gfxboot-branding-openSUSE
Requires:       git
Requires:       greetd
Requires:       grep
Requires:       gzip
Requires:       (gtkgreet or wlgreet)
Suggests:       imv
Requires:       jq
Requires:       less
Recommends:     libqt5-qtwayland
Suggests:       mpv
Requires:       pipewire
Recommends:     qt5ct
Requires:       sudo
Requires:       sway-branding-openSUSE
Requires:       tar
Suggests:       vifm
Suggests:       vim
Requires:       clipman
Requires:       mpris-ctl
Requires:       sway-marker
Requires:       waybar-branding-openSUSE
Requires:       wget
Requires:       wl-clipboard
Requires:       xdg-desktop-portal
Requires:       xdg-desktop-portal-wlr
Requires:       xdg-utils

%description
This meta package aggregates openSUSEway desktop enviroment packages.

%package -n     patterns-openSUSEway
%pattern_graphicalenvironments
Summary:        The openSUSEway desktop environment pattern
Group:          Metapackages
Provides:       pattern() = openSUSEway
Provides:       pattern-icon() = pattern-sway
Provides:       pattern-order() = 1460
Provides:       pattern-visible()
URL:            https://github.com/openSUSE/openSUSEway
BuildRequires:  patterns-rpm-macros
Requires:       openSUSEway

%description -n patterns-openSUSEway
This pattern installs the openSUSE look and feel for sway.

%package -n     sway-branding-openSUSE
Summary:        openSUSE branding of sway
Group:          System/GUI/Other
BuildRequires:  sway
Requires:       SwayNotificationCenter
Requires:       bc
Requires:       brightnessctl
Requires:       fontawesome-fonts
Requires:       jq
Requires:       pamixer
Requires:       patterns-sway-sway
Requires:       pavucontrol
Requires:       playerctl
Requires:       polkit-gnome
Requires:       sway
Requires:       wallpaper-branding-openSUSE
Requires:       wob
Provides:       sway-branding = %{version}
Conflicts:      sway-branding
Supplements:    (sway and branding-openSUSE)

#BRAND: /etc/sway/config and /etc/sway/config.d/
#BRAND: contain openSUSE config and branding

%description -n sway-branding-openSUSE
This package provides the openSUSE look and feel for sway.

%package -n     waybar-branding-openSUSE
Summary:        openSUSE branding of waybar
Group:          System/GUI/Other
BuildRequires:  waybar
Provides:       waybar-branding = %{version}
Conflicts:      waybar-branding
Supplements:    (waybar and branding-openSUSE)

#BRAND: /etc/xdg/waybar/config and /etc/xdg/waybar/style.css
#BRAND: contain openSUSE config and branding

%description -n waybar-branding-openSUSE
This package provides the openSUSE look and feel for waybar.

%prep
%autosetup -p1 -n openSUSEway-%{version}

%build

%install

## openSUSEway package
### qt5ct config to configure dark theme
install -D -p -m 644 qt5ct.conf %{buildroot}%{_sysconfdir}/xdg/qt5ct/qt5ct.conf
### greetd as a login manager
install -D -p -m 644 greetd/sway-config %{buildroot}%{_sysconfdir}/greetd/sway-config
install -D -p -m 644 greetd/config.toml %{buildroot}%{_sysconfdir}/greetd/config.toml.way
install -D -p -m 644 greetd/environments %{buildroot}%{_sysconfdir}/greetd/environments
install -D -p -m 644 greetd/style.css %{buildroot}%{_sysconfdir}/greetd/style.css

## openSUSEway pattern package
mkdir -p %{buildroot}/%{_defaultdocdir}/patterns/
echo 'This file marks the pattern openSUSEway to be installed.' >%{buildroot}%{_defaultdocdir}/patterns/openSUSEway.txt

## Sway
install -D -p -m 644 .config/sway/config %{buildroot}%{_sysconfdir}/sway/config
install -D -p -m 644 .config/sway/env %{buildroot}%{_sysconfdir}/sway/env
install -D -p -m 644 .config/sway/config.d/50-openSUSE.conf %{buildroot}%{_sysconfdir}/sway/config.d/50-openSUSE.conf

install -D -p -m 644 sway/sway-session.target %{buildroot}%{_prefix}/lib/systemd/user/sway-session.target
install -D -p -m 644 sway/sway.service %{buildroot}%{_prefix}/lib/systemd/user/sway.service
install -D -p -m 644 sway/sway.desktop %{buildroot}%{_datadir}/wayland-sessions/sway.desktop.brand
install -D -p -m 755 sway/sway-run.sh %{buildroot}%{_bindir}/sway-run.sh

### alacritty
# so far doesn't have special branding package and it doesn't support system wide config
install -D -p -m 644 .config/alacritty/alacritty.yml %{buildroot}%{_sysconfdir}/alacritty/alacritty.yml

## wofi
install -D -p -m 644 .config/wofi/config %{buildroot}%{_sysconfdir}/wofi/config
install -D -p -m 644 .config/wofi/style.css %{buildroot}%{_sysconfdir}/wofi/style.css
#set wofi config and style to the system dir
sed -i -e "s|wofi --show.*|wofi --conf=%{_sysconfdir}/wofi/config --style=%{_sysconfdir}/wofi/style.css|g" %{buildroot}%{_sysconfdir}/sway/config.d/50-openSUSE.conf

## waybar
install -D -p -m 644 .config/waybar/config %{buildroot}%{_sysconfdir}/xdg/waybar/config
install -D -p -m 644 .config/waybar/style.css %{buildroot}%{_sysconfdir}/xdg/waybar/style.css
install -D -p -m 755 .config/waybar/scratchpad-indicator.sh %{buildroot}%{_datadir}/openSUSEway/helpers/scratchpad-indicator.sh

## wob
install -D -p -m 644 .config/wob/wob.ini %{buildroot}%{_sysconfdir}/sway/wob/wob.ini

## swaync
install -D -p -m 644 .config/swaync/config.json %{buildroot}%{_sysconfdir}/sway/swaync/config.json
install -D -p -m 644 .config/swaync/style.css %{buildroot}%{_sysconfdir}/sway/swaync/style.css

%pre -n openSUSEway
# bug #1176195, don't force enviroment, cleaning up old installations
test -e %{_sysconfdir}/profile.d/openSUSEway.sh && rm %{_sysconfdir}/profile.d/openSUSEway.sh || true
test -e %{_prefix}/lib/environment.d/50-openSUSEway.conf && rm %{_prefix}/lib/environment.d/50-openSUSEway.conf || true

%post -n openSUSEway
test -e %{_sysconfdir}/greetd/config.toml && \
    mv -n %{_sysconfdir}/greetd/config.toml %{_sysconfdir}/greetd/config.toml.orig || true
cp %{_sysconfdir}/greetd/config.toml.way %{_sysconfdir}/greetd/config.toml

%postun -n openSUSEway
test -e %{_sysconfdir}/greetd/config.toml.orig && \
    mv %{_sysconfdir}/greetd/config.toml.orig %{_sysconfdir}/greetd/config.toml || true

%pre -n sway-branding-openSUSE
%service_add_pre sway-session.target sway.service

%post -n sway-branding-openSUSE
test -e %{_datadir}/wayland-sessions/sway.desktop && \
    mv -n %{_datadir}/wayland-sessions/sway.desktop %{_datadir}/wayland-sessions/sway.desktop.orig || true
cp %{_datadir}/wayland-sessions/sway.desktop.brand %{_datadir}/wayland-sessions/sway.desktop
%service_add_post sway-session.target sway.service

%preun -n sway-branding-openSUSE
%service_del_preun sway-session.target sway.service

%postun -n sway-branding-openSUSE
test -e %{_datadir}/wayland-sessions/sway.desktop.orig && \
    mv %{_datadir}/wayland-sessions/sway.desktop.orig %{_datadir}/wayland-sessions/sway.desktop || true
%service_del_postun sway-session.target sway.service

%files
%dir %{_sysconfdir}/xdg/qt5ct/
%config(noreplace) %{_sysconfdir}/xdg/qt5ct/qt5ct.conf
%dir %{_sysconfdir}/greetd/
%attr(644,greeter,greeter) %config %{_sysconfdir}/greetd/config.toml.way
%attr(644,greeter,greeter) %config %{_sysconfdir}/greetd/sway-config
%attr(644,greeter,greeter) %config %{_sysconfdir}/greetd/environments
%attr(644,greeter,greeter) %config %{_sysconfdir}/greetd/style.css
%dir %{_datadir}/openSUSEway/
%dir %{_datadir}/openSUSEway/helpers/

%files -n patterns-openSUSEway
%dir %{_defaultdocdir}/patterns
%{_defaultdocdir}/patterns/openSUSEway.txt

%files -n sway-branding-openSUSE
%dir %{_sysconfdir}/sway
%config %{_sysconfdir}/sway/config
%config %{_sysconfdir}/sway/env
%dir %{_sysconfdir}/sway/config.d
%config %{_sysconfdir}/sway/config.d/50-openSUSE.conf
%{_prefix}/lib/systemd/user/sway-session.target
%{_prefix}/lib/systemd/user/sway.service
%{_datadir}/wayland-sessions/sway.desktop.brand
%{_bindir}/sway-run.sh

%dir %{_sysconfdir}/alacritty
%config(noreplace) %{_sysconfdir}/alacritty/alacritty.yml

%dir %{_sysconfdir}/wofi
%config(noreplace) %{_sysconfdir}/wofi/config
%config(noreplace) %{_sysconfdir}/wofi/style.css

%dir %{_sysconfdir}/sway/wob
%config %{_sysconfdir}/sway/wob/wob.ini

%dir %{_sysconfdir}/sway/swaync
%config %{_sysconfdir}/sway/swaync/config.json
%config %{_sysconfdir}/sway/swaync/style.css

%files -n waybar-branding-openSUSE
%dir %{_sysconfdir}/xdg/waybar
%config(noreplace) %{_sysconfdir}/xdg/waybar/config
%config(noreplace) %{_sysconfdir}/xdg/waybar/style.css
%{_datadir}/openSUSEway/helpers/scratchpad-indicator.sh

%changelog
* Wed May 31 2023 Denys Kondratenko <stdden@opensuse.org>
- Update to version 0.15.2:
  * Install sway systemd components to the correct directories by @FilippoBonazziSUSE in #98
  * Add SwayNotificationCenter icon to waybar by default by @FilippoBonazziSUSE in #107
  * Fix spec file errors by @FilippoBonazziSUSE in #100
  * Start sway-session systemd target when starting sway by @FilippoBonazziSUSE in #108
  * Package scratchpad-indicator helper by @FilippoBonazziSUSE in #109
  * Add style.css to the package by @denisok in #115
  * Allow sway to be run with proprietary drivers by @joantolo in #114
* Wed Feb 22 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Update to version 0.15.1:
  * Fix greetd grey screen delay
- Add set_version manual service
* Fri Feb  3 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Automatically format the spec file after extracting it.
  Any meaningful changes can be manually fed back to the upstream Git repo.
* Fri Feb  3 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Automatically extract the spec file
  The spec file is now maintained in Git. The `extract` parameter of the
  `obs_scm` service allows you to automatically extract the file from the
  obscpio archive when running the service, updating the OBS copy of the spec
  file to the upstream maintained one.
* Wed Feb  1 2023 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Add _service file, replace .tar.gz with .obscpio
* Mon Jan 30 2023 Denys Kondratenko <stdden@opensuse.org>
- New in 0.15 release
  * Use new option for window opacity by @baierjan in #56
  * Add openSUSE wob theme by @FilippoBonazziSUSE in #68
  * Improve some defaults by @FilippoBonazziSUSE in #73
  * add calendar tooltip, new weekday format by @denisok in #71
  * fix some readme typos by @AlessandroMinoccheri in #78
  * add scratchpad indicator by @denisok in #70
  * Import user configuration variables by @FilippoBonazziSUSE in #77
  * Add SwayNotificationCenter config and theme by @FilippoBonazziSUSE in #76
  * Import all user configuration variables from environment.d by @FilippoBonazziSUSE in #82
  * System mode menu by @FilippoBonazziSUSE in #90
  * Add swaync configuration in waybar and hotkey by @FilippoBonazziSUSE in #83
  * Add wob.ini configuration file for wob>=0.14 by @FilippoBonazziSUSE in #84
  * Improve README, add screenshot by @FilippoBonazziSUSE in #94
  * changes for 0.15 by @denisok in #91
* Tue Jan 24 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavor.
* Tue Nov  2 2021 Denys Kondratenko <stdden@opensuse.org>
- New in 0.14 release
  * Add configuration for Play/Pause, Next, Prev multimedia keys. by @mcepl in #41i
  * * removes add-configuration-for-play-pause-next-prev-multimedi.patch
  * Allow users different MPRIS handler for multimedia keys. by @mcepl in #43
  * number of packages to update indicator to waybar by @denisok in #44
  * add style to gtkgreet to match openSUSEway theme by @denisok in #45
  * Use late evaluation of $term variable for bindsym $mod+Return by @mcepl in #46
  * Fixes greeter if GDM installed. GDM messes up tty1 by @denisok in #53.
* Mon Apr 26 2021 Matej Cepl <mcepl@suse.com>
- Added add-configuration-for-play-pause-next-prev-multimedi.patch
* Thu Mar 25 2021 Matej Cepl <mcepl@suse.com>
- Relax requirements somehow
* Tue Jan 19 2021 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.13 release
  * Allow root app to run on the user session, fixes #21
  * Include pamixer in the pattern, fixes #32
* Tue Nov 17 2020 Fabian Vogt <fvogt@suse.com>
- Move %%pattern_graphicalenvironments to the proper section
- Drop unused betatest bcond
* Mon Oct 12 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.12 release
  * Allow increasing volume over 100%%
  * Add bc to the sway-branding requirement
* Tue Sep 15 2020 Fabian Vogt <fvogt@suse.com>
- Make patterns-openSUSEway properly behaved:
  * Use proper description (it's very user visible!)
  * Don't overwrite the category (set by %%pattern_graphicalenvironments)
* Fri Sep 11 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.11 release
  * greetd support fixes #27
  * correct environment for sway session, fixes #28, bsc#1176195
- Remove old files from environment enforcing, bsc#1176195
- Add greetd support
* Tue Sep  8 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add gfxboot and gfxboot-branding-openSUSE to have better boot experience
* Sun Aug 30 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.10 release
  * don't force qt theme, fixes #24
* Wed Aug  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add pipewire and xdg-desktop-portal-wlr for the screensharing, fixes #13
* Tue Aug  4 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.9 release
  * fix gtk cursor and icon theme, fixes #22
  * correct brightness adjustment indicator, fixes #23
  * include all user custom configs
- fix name in enviroment.d to 50-openSUSEway.sh
* Fri Jul 31 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.8 release
  * Add wob support
  * pamixer is dependency for wob controls in config
- Add command-not-found to the environment
* Mon Jul 20 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New in 0.7 release
  * update sway conf to the 1.5
  * adding GTK and QT themes
* Tue Jul 14 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New 0.6 release
  * Enforce tty branding in the branded sway
  * Don't start mako explicitly
  * Only include sway config files with .conf file extension
- Add initial requirements to the openSUSEway desktop meta package
  * add openSUSEway pattern
* Mon Jun 22 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- New 0.3 release
  * fixes double status bar issue
- Remove uneeded Requires for branding packages
* Fri Jun 19 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Fix typo in the Source URL
* Fri Jun  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add waybar branding package
- Add alacritty customization
* Fri Jun  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add metapackage in order to store more brandings packages under
* Fri Jun  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add wofi config and style to sysconfdir
  * wofi doesn't support distibution specific dirs from package
  * spec seds distro specific dirs to sway config for wofi
* Fri Jun  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add Source URL and build from archive
* Fri May 29 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Initial package to brand Sway in openSUSE way
